@@ -1,9 +1,9 @@
 ! ==============================================================================
 !   ENGLISH:  Language Definition File
 !
-!   Supplied for use with Inform 6 -- Release 6.12.4 -- Serial number 200718
+!   Supplied for use with Inform 6 -- Release 6.12.8 -- Serial number 251226
 !
-!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2020
+!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2025
 !
 !   This code is licensed under either the traditional Inform license as
 !   described by the DM4 or the Artistic License version 2.0.  See the
@@ -322,7 +322,7 @@ Array LanguageGNAsToArticles --> 0 0 0 1 1 1 0 0 0 1 1 1;
 ! ----------------------------------------------------------------------------
 
 [ LanguageVerbLikesAdverb w;
-    if (w == 'look' or 'go' or 'push' or 'walk')
+    if (w == 'look' or 'go' or 'run' or 'leave' or 'l//' or 'push' or 'walk')
         rtrue;
     rfalse;
 ];
@@ -883,6 +883,13 @@ Constant LIBRARYV__TX   = " Library v";
                          "didn't have");
             " ", (the) x1, ".";
         3:  "Dropped.";
+        4: CSubjectVerb(actor, false, false, "need to take", 0, 0, "had to take");
+           print " ", (the) x1, " ";
+           if (x2 has container)
+               print "out";
+           else
+               print "off";
+           " of ", (the) x2, " before dropping ", (ItOrThem) x1, ".";
     }
   Eat: switch (n) {
         1:  CSubjectIs(x1,true); " plainly inedible.";
@@ -979,8 +986,8 @@ Constant LIBRARYV__TX   = " Library v";
         2:  CSubjectCant(actor,true); " go that way.";
         3:  CSubjectIs  (actor,true); " unable to climb ", (the) x1, ".";
         4:  CSubjectIs  (actor,true); " unable to descend by ", (the) x1, ".";
-        5:  CSubjectCant(actor,true); " since ", (the) x1, " ", (IsOrAre) x1, " in the way.";
-        6:  CSubjectCant(actor,true); " since ", (the) x1, " ", (nop) PluralObj(x1,"lead","leads","led"), " nowhere.";
+        5:  CSubjectCant(actor,true); ", since ", (the) x1, " ", (IsOrAre) x1, " in the way.";
+        6:  CSubjectCant(actor,true); ", since ", (the) x1, " ", (nop) PluralObj(x1,"lead","leads","led"), " nowhere.";
         7:  CSubjectVerb(actor,false,false,"depart",0,"departs","departed"); ".";
     }
   Insert: switch (n) {
@@ -1112,7 +1119,8 @@ Constant LIBRARYV__TX   = " Library v";
             print " ";
         5:  print "^Would you like to RESTART, RESTORE a saved game";
             #Ifdef DEATH_MENTION_UNDO;
-            print ", UNDO your last move";
+	    if (undo_flag ~= 0)
+		print ", UNDO your last move";
             #Endif;
             if (TASKS_PROVIDED == 0) print ", give the FULL score for that game";
             if (deadflag == 2 && AMUSING_PROVIDED == 0)
@@ -1315,6 +1323,8 @@ Constant LIBRARYV__TX   = " Library v";
         2:  print "But ";
             CSubjectIsnt(x1,true,true); " there now.";
         3:  "Removed.";
+        4:  print "But ";
+            CSubjectIsnt(x1,true,true); " in or on anything.";
     }
   Restart: switch (n) {
         1:  print "Are you sure you want to restart? ";
@@ -1458,7 +1468,7 @@ Constant LIBRARYV__TX   = " Library v";
             print " have ";
             Tense("", "had ");
             "to get ", (nop) SupportObj(x1,"off","out of"), " ", (the) x1, " first.";
-        5:  CSubjectVerb(actor,true,false,"already have",0,"already has","already had"); " ", (ThatOrThose) x1, ".";
+        5:  CSubjectVerb(actor,true,false,"already have",0,"already has","already had"); " ", (the) x1, ".";
         6:  CSubjectVerb(x2,true,false,"seem",0,"seems","seemed"); " to belong to ", (the) x1, ".";
         7:  CSubjectVerb(x2,true,false,"seem",0,"seems","seemed"); " to be a part of ", (the) x1, ".";
         8:  CSubjectIs  (x1,true); " not available.";
@@ -1467,8 +1477,6 @@ Constant LIBRARYV__TX   = " Library v";
         11: CSubjectIs  (x1,true); " fixed in place.";
         12: CSubjectIs  (actor,true); " carrying too many things already.";
         13: "(putting ", (the) x1, " into ", (the) x2, " to make room)";
-	14: CSubjectVerb(actor, false, false, "should take", 0, 0, "should have taken");
-	    " ", (the) x1, " first.";
     }
   Taste: switch (n) {
         1:  CSubjectVerb(actor,true,false,"taste",0,"tastes","tasted"); " nothing unexpected.";
@@ -1502,6 +1510,10 @@ Constant LIBRARYV__TX   = " Library v";
             Tense("serve", "have served");
             " any purpose.";
     }
+  Transfer: switch (n) {
+        1: CSubjectIs(actor, false); " still holding ", (the) x1, ".";
+    }
+
 ! Turn: see Pull.
   Unlock:  switch (n) {
         1:  CSubjectDont(x1,true);
@@ -1552,6 +1564,13 @@ Constant LIBRARYV__TX   = " Library v";
         2:  CSubjectIs  (actor,true); " not holding ", (ThatOrThose) x1, ".";
         3:  CSubjectIs  (actor,true); " already wearing ", (ThatOrThose) x1, ".";
         4:  CSubjectVerb(actor,false,false,"put on",0,"puts on","put on"); " ", (the) x1, ".";
+        5:  CSubjectVerb(actor, false, false, "need to take", 0, 0, "had to take");
+            print " ", (the) x1, " ";
+            if (x2 has container)
+                print "out";
+            else
+                print "off";
+            " of ", (the) x2, " before wearing ", (ItOrThem) x1, ".";
     }
 ! Yes:  see No.
 ];
