@@ -1,9 +1,9 @@
 ! ==============================================================================
 !   GRAMMAR:  Grammar table entries for the standard verbs library.
 !
-!   Supplied for use with Inform 6 -- Release 6.12.4 -- Serial number 200718
+!   Supplied for use with Inform 6 -- Release 6.12.8 -- Serial number 251226
 !
-!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2020
+!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2025
 !   This code is licensed under either the traditional Inform license as
 !   described by the DM4 or the Artistic License version 2.0.  See the
 !   file COPYING in the distribution archive or at
@@ -17,9 +17,9 @@
 
 System_file;
 
-#Ifdef		LIBRARY_STAGE;
-#Iffalse	LIBRARY_STAGE >= AFTER_GRAMMAR;	! if not already included
-#Iftrue		LIBRARY_STAGE == AFTER_VERBLIB;	! if okay to include it
+#Ifdef      LIBRARY_STAGE;
+#Iffalse    LIBRARY_STAGE >= AFTER_GRAMMAR;  ! if not already included
+#Iftrue     LIBRARY_STAGE == AFTER_VERBLIB;  ! if okay to include it
 
 ! ------------------------------------------------------------------------------
 !  The "meta-verbs", commands to the game rather than in the game, come first:
@@ -182,6 +182,9 @@ Verb meta 'glklist'
 ! ------------------------------------------------------------------------------
 
 [ ADirection; if (noun in Compass) rtrue; rfalse; ];
+[ NotPlayer; if (noun ~= player) rtrue; rfalse; ];
+[ IsPlayer; if (noun == player) rtrue; rfalse; ];
+
 
 Verb 'answer' 'say' 'shout' 'speak'
     * topic 'to' creature                       -> Answer;
@@ -211,6 +214,11 @@ Verb 'burn' 'light'
 Verb 'buy' 'purchase'
     * noun                                      -> Buy;
 
+Verb 'carry'
+    * multi                                     -> Take
+    * multiinside 'from'/'off' noun             -> Remove
+    * 'inventory'                               -> Inv;
+
 Verb 'climb' 'scale'
     * noun                                      -> Climb
     * 'up'/'over' noun                          -> Climb;
@@ -235,7 +243,7 @@ Verb 'dig'
 
 
 Verb 'disrobe' 'doff' 'shed'
-    * held                                      -> Disrobe;
+    * multi                                     -> Disrobe;
 
 Verb 'drink' 'sip' 'swallow'
     * noun                                      -> Drink;
@@ -245,10 +253,6 @@ Verb 'drop' 'discard'
     * multiexcept 'in'/'into'/'down' noun       -> Insert
     * multiexcept 'on'/'onto' noun              -> PutOn;
 
-Verb 'throw'
-    * noun					-> ThrowAt
-    * held 'at'/'against'/'on'/'onto' noun      -> ThrowAt;
-
 Verb 'eat'
     * held                                      -> Eat;
 
@@ -293,6 +297,11 @@ Verb 'go' 'run' 'walk'
     * 'in'/'inside'                             -> GoIn
     * 'into'/'in'/'inside'/'through' noun       -> Enter;
 
+Verb 'hold'
+    * multi                                     -> Take
+    * multiinside 'from'/'off' noun             -> Remove
+    * 'inventory'                               -> Inv;
+
 Verb 'in' 'inside'
     *                                           -> GoIn;
 
@@ -372,7 +381,7 @@ Verb 'push' 'clear' 'move' 'press' 'shift'
 Verb 'put'
     * multiexcept 'in'/'inside'/'into' noun     -> Insert
     * multiexcept 'on'/'onto' noun              -> PutOn
-    * 'on' held                                 -> Wear
+    * 'on' multiheld                            -> Wear
     * 'down' multiheld                          -> Drop
     * multiheld 'down'                          -> Drop;
 
@@ -382,8 +391,8 @@ Verb 'read'
     * topic 'in' noun                           -> Consult;
 
 Verb 'remove'
-    * held                                      -> Disrobe
-    * multi                                     -> Take
+    * worn                                      -> Disrobe
+    * multi                                     -> Remove
     * multiinside 'from' noun                   -> Remove;
 
 Verb 'rub' 'clean' 'dust' 'polish' 'scrub'
@@ -397,14 +406,14 @@ Verb 'set' 'adjust'
     * noun                                      -> Set
     * noun 'to' special                         -> SetTo;
 
-Verb 'show' 'display' 'present'
-    * creature held                             -> Show reverse
-    * held 'to' creature                        -> Show;
-
 Verb 'shit' 'damn' 'fuck' 'sod'
     *                                           -> Strong
     * topic                                     -> Strong;
 
+Verb 'show' 'display' 'present'
+    * creature held                             -> Show reverse
+    * held 'to' creature                        -> Show;
+
 Verb 'sing'
     *                                           -> Sing;
 
@@ -444,9 +453,9 @@ Verb 'switch'
     * 'on' noun                                 -> SwitchOn
     * 'off' noun                                -> SwitchOff;
 
-Verb 'take' 'carry' 'hold'
+Verb 'take'
     * multi                                     -> Take
-    * 'off' held                                -> Disrobe
+    * 'off' multiheld                           -> Disrobe
     * multiinside 'from'/'off' noun             -> Remove
     * 'inventory'                               -> Inv;
 
@@ -460,6 +469,10 @@ Verb 'tell'
 Verb 'think'
     *                                           -> Think;
 
+Verb 'throw'
+    * noun                                      -> ThrowAt
+    * held 'at'/'against'/'on'/'onto' noun      -> ThrowAt;
+
 Verb 'tie' 'attach' 'connect' 'fasten' 'fix'
     * noun                                      -> Tie
     * noun 'to' noun                            -> Tie;
@@ -468,7 +481,8 @@ Verb 'touch' 'feel' 'fondle' 'grope'
     * noun                                      -> Touch;
 
 Verb 'transfer'
-    * noun 'to' noun                            -> Transfer;
+    * noun 'to' noun=NotPlayer                  -> Transfer
+    * noun 'to' noun=IsPlayer                  -> Take;
 
 Verb 'turn' 'rotate' 'screw' 'twist' 'unscrew'
     * noun                                      -> Turn
@@ -497,7 +511,7 @@ Verb 'wave'
     * 'at' noun                                 -> WaveHands;
 
 Verb 'wear' 'don'
-    * held                                      -> Wear;
+    * multiheld                                 -> Wear;
 
 Verb 'yes' 'y//'
     *                                           -> Yes;
@@ -526,10 +540,10 @@ Verb 'yes' 'y//'
 !  Final task: provide trivial routines if the user hasn't already:
 ! ------------------------------------------------------------------------------
 
-Default Story           0;
-Default Headline        0;
-Default d_obj           NULL;
-Default u_obj           NULL;
+Default Story          0;
+Default Headline       0;
+Default d_obj          NULL;
+Default u_obj          NULL;
 
 Stub AfterLife         0;
 Stub AfterPrompt       0;
@@ -576,15 +590,15 @@ Include "infix";
 
 Undef LIBRARY_STAGE; Constant LIBRARY_STAGE = AFTER_GRAMMAR;
 
-#Ifnot;		! LIBRARY_STAGE < AFTER_GRAMMAR but ~= AFTER_VERBLIB
+#Ifnot;     ! LIBRARY_STAGE < AFTER_GRAMMAR but ~= AFTER_VERBLIB
 Message "Error: 'verblib' needs to be correctly included before including 'grammar'. This will cause a big number of errors!";
 #Endif;
 
-#Ifnot;		! LIBRARY_STAGE >= AFTER_GRAMMAR : already included
+#Ifnot;     ! LIBRARY_STAGE >= AFTER_GRAMMAR : already included
 Message "Warning: 'grammar' included twice; ignoring second inclusion. (Ignore this if this is on purpose.)";
 #Endif;
 
-#Ifnot;		! LIBRARY_STAGE is not defined
+#Ifnot;     ! LIBRARY_STAGE is not defined
 Message "Error: 'parser', then 'verblib' need to be correctly included before including 'grammar'. This will cause a big number of errors!";
 #Endif;
 
