@@ -1,9 +1,9 @@
 ! ==============================================================================
 !   INFIX:  Support for the optional library debugger extension "Infix".
 !
-!   Supplied for use with Inform 6 -- Release 6.12.6 -- Serial number 220219
+!   Supplied for use with Inform 6 -- Release 6.12.8 -- Serial number 251226
 !
-!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2022
+!   Copyright Graham Nelson 1993-2004 and David Griffith 2012-2025
 !
 !   This code is licensed under either the traditional Inform license as
 !   described by the DM4 or the Artistic License version 2.0.  See the
@@ -1166,9 +1166,9 @@ Verb meta ';i' ';inv' ';inventory'
     *                                           -> InfixInv;
 Verb meta ';x' ';examine'
     * InfixRvalue                               -> InfixExamine;
-Verb meta ';xo' ';examineo'
+Verb meta ';xo' ';exo'
     * InfixRvalue                               -> InfixExamineO;
-Verb meta ';xs' ';examines'
+Verb meta ';xs' ';exs'
     * InfixRvalue                               -> InfixExamineS;
 Verb meta ';<'
     * InfixActionToken                          -> InfixAction
